@@ -250,7 +250,7 @@ static void con_ic_connection_finalize(GObject *obj)
 	con_ic_connection_clear_proxy_settings(connection);
 
 	objects = g_slist_remove(objects, connection);
-	if (objects == NULL) {
+	if (objects == NULL && dbus_connection != NULL) {
 		/* If all objects were deleted, unref DBUS stuff */
 		dbus_connection_unregister_object_path(dbus_connection,
 						       ICD_DBUS_PATH);
